# EcoOpen

Open data surveying and analysis. Inspired by a similar project, [oddpub](https://github.com/quest-bih/oddpub) however, this project is focused on the environment and sustainability and adds the use of LLM (Large Language Models) for data acquisition and analysis.


v0.1.0a